# SettingItemWithOperationsInformationContext

The context where this setting item is effective.

## Enum

* `TENANT` (value: `'Tenant'`)

* `ENTITY` (value: `'Entity'`)

* `USER` (value: `'User'`)

* `NONE` (value: `'None'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


